obmenka tracker
===============

:info: Keep Calm and Buy the USD

.. image:: https://raw.githubusercontent.com/hellysmile/obmenka/master/preview.png
    :target: http://obmenka.kharkov.ua/

Installation Mac OS X:
**********************

.. code-block:: bash

    brew install libxml2 libxslt

    # optional
    # virtualenv env
    # source env/bin/activate
    # or just use sudo

    pip install obmenka

Usage:
******

.. code-block:: bash

    obmenka
